ScrapyRT documentation
======================

**ScrapyRT** is an HTTP server that provides an API for scheduling :doc:`Scrapy
<scrapy:index>` spiders and making requests with spiders.

.. toctree::
   :maxdepth: 2

   api
   changes
